<?php
/**
 * @file
 * This file is part of the Twizo Drupal 7 2fa extension.
 *
 * (c) Twizo <info@twizo.com>
 *
 * For the full copyright and license information, please view the LICENSE
 * File that was distributed with this source code.
 */

function twizo_admin_form($form, &$form_state){
    // Checks if the Twizo library is present.
    if(module_exists('libraries') && function_exists('libraries_detect')){
        $library = libraries_detect('twizo');
        if (!$library['installed']){
            $twizo_error = t('Error while detecting the Twizo library. Please install the Twizo library with composer.');
            drupal_set_message($twizo_error, 'error');
        } else{
            twizo_command('checkApiKey', null);
        }
    } elseif(!file_exists(DRUPAL_ROOT . '/vendor/twizo/lib-api-php/autoload.php')){
        drupal_set_message(t('Twizo php library not found! Please install the Twizo module with composer.'), 'error');
    }
    if (variable_get('widget_logo')){
        $url = parse_url(variable_get('widget_logo'));
        if($url['scheme'] == 'http'){
            drupal_set_message(t('Logo uses a HTTP protocol, HTTPS is recommended.'), 'error');
        }
    }
    $form['twizo_api_key'] = array(
        '#type' => 'textfield',
        '#title' => t('Twizo API key'),
        '#description' => t('API keys can be found at <a href="https://portal.twizo.com/applications/">https://portal.twizo.com/applications/</a>.'),
        '#size' => 40,
        '#maxlength' => 255,
        '#default_value' => !empty(variable_get('twizo_api_key')) ? variable_get('twizo_api_key') : '',
    );
    $form['twizo_api_server'] = array(
        '#type' => 'select',
        '#title' => t('API server location'),
        '#default_value' => !empty(variable_get('twizo_api_server')) ? variable_get('twizo_api_server') : twizo_get_api_servers()['api-asia-01.twizo.com'],
        '#options' => twizo_get_api_servers(),
        '#description' => t('Select server location'),
    );
    $form['twizo_sender'] = array(
        '#type' => 'textfield',
        '#title' => t('Default sender'),
        '#description' => t('Set your default sender'),
        '#size' => 40,
        '#maxlength' => 128,
        '#default_value' => !empty(variable_get('twizo_sender')) ? variable_get('twizo_sender') : NULL,
    );
    $form['widget_logo'] = array(
        '#type' => 'textfield',
        '#title' => t('Widget site logo path'),
        '#description' => t('Website url to logo link (200x90px recommended).'),
        '#size' => 40,
        '#maxlength' => 512,
        '#default_value' => !empty(variable_get('widget_logo')) ? variable_get('widget_logo') : NULL,
    );
    $form['twizo_enable_widget'] = array(
        '#type' => 'checkbox',
        '#title' => t('Enable two factor authentication'),
        '#default_value' => !empty(variable_get('twizo_enable_widget')) ? variable_get('twizo_enable_widget') : FALSE,
    );
    if(variable_get('twizo_enable_widget')) {
        $form['twizo_enable_backupcode'] = array(
            '#type' => 'checkbox',
            '#title' => t('Enable backup codes'),
            '#default_value' => !empty(variable_get('twizo_enable_backupcode')) ? variable_get('twizo_enable_backupcode') : FALSE,
        );
    }
    return system_settings_form($form);
}

/**
 * Admin form for sending test messages.
 */
function twizo_admin_test_form($form, &$form_state){
    $form['recipient'] = array(
        '#type' => 'textfield',
        '#required' => TRUE,
        '#title' => t('Phone Number'),
        '#description' => t('The number to send your message to. Include all numbers except the country code'),
    );
    $form['sender'] = array(
        '#type' => 'textfield',
        'required' => FALSE,
        '#title' => t('Sender'),
        '#description' => t('The sender of the message.'),
    );
    $form['message'] = array(
        '#type' => 'textarea',
        '#required' => TRUE,
        '#title' => t('Message'),
        '#description' => t("The body of your SMS message.")
    );
    $form['submit'] = array(
        '#type' => 'submit',
        '#value' => t('Send SMS'),
    );
    return $form;
}

/**
 * Validation handler.
 */
function twilio_admin_test_form_validate($form, &$form_state){
    $value = $form_state['values']['recipient'];
    if (!is_numeric($value)) {
        form_set_error('recipient', t('You must enter a phone number!'));
    }
}

/**
 * Submit handler.
 */
function twizo_admin_test_form_submit($form, &$form_state){
    $send = twizo_send($form_state['values']['message'],
        $form_state['values']['recipient'],
        $form_state['values']['sender']
    );

    if($send){
        drupal_set_message(t('Your message has been sent.'));
    }
    else{
        drupal_set_message(t('Something went wrong with sending your message.'), 'error');
    }
}




