<?php
/**
 * @file
 * This file is part of the Twizo Drupal 7 2fa extension.
 *
 * (c) Twizo <info@twizo.com>
 *
 * For the full copyright and license information, please view the LICENSE
 * File that was distributed with this source code.
 */

/**
 * Callback for widget login, handles the 2fa login method.
 * @param $form
 * @param $form_state
 * @return array
 */
function twizo_widget_login(&$form = NULL, &$form_state = NULL){
    global $user;
    // Get uid if form_state isset, else get the uid with the ajax post.
    $uid = isset($form_state['values']['name']) ? user_authenticate($form_state['values']['name'], $form_state['values']['pass']) : user_authenticate($_POST['name'], $_POST['pass']);
    $account = user_load($uid);
    $phoneNumber = twizo_get_user_phonenumber($uid, $form_state) != NULL ? twizo_get_user_phonenumber($uid, $form_state) : $_POST['number'];
    $sessionToken = isset($_POST['sessionToken']) ? $_POST['sessionToken'] : NULL;
    $isTrusted = isset($_POST['isTrusted']) ? $_POST['isTrusted'] : NULL;

    // Checks if cookie for trusted device has been set.
    if(twizo_check_cookie($account)){
        $user = user_load($uid, TRUE);
        return twizo_reload_page();
    }
    // If no sessiontoken has been set the widget wil be activated
    elseif (!isset($sessionToken)) {
        return twizo_widget_check($form_state, $phoneNumber, $account, $uid);

    }
    else {
        // Set a cookie for trusted device if the user has enabled it
        if($isTrusted == 'true'){
            $data = array(
                'uid' => $uid,
            );
            twizo_command('setTrusted', $data);
        }
        $data = array(
            'sessionToken' => $sessionToken,
            'number' => $phoneNumber,
            'name' => $_POST['name'],
            'pass' => $_POST['pass'],
        );
        // Gets the status of the widget from the Twizo API
        $widgetStatus = twizo_command('getWidgetStatus', $data);
        if ($widgetStatus == 'success') {
            $user = user_load($uid, TRUE);
            return $form;
        } else {
            drupal_set_message('Widget verification failed.', 'error');
            return twizo_reload_page();
        }
    }
}

/**
 * @return array
 */
function twizo_reload_page() {
    $commands[] = ajax_command_invoke(NULL, 'reload');

    return array(
        '#type' => 'ajax',
        '#commands' => $commands,
    );
}

/**
 * Checks if the user has enabled 2fa and a verified number.
 * @param $form_state
 * @param $phoneNumber
 * @param $account
 * @param $uid
 * @return array
 */
function twizo_widget_check(&$form_state, $phoneNumber, $account, $uid) {
    global $user;
    // Checks if a phone number is added to the user account
    if (isset($phoneNumber) && $account->twizo_user['widgetenabled'] == 1) {
        $data = array(
            'number' => $phoneNumber,
            'name' => $form_state['values']['name'],
            'pass' => $form_state['values']['pass'],
        );
        twizo_command('widgetSession', $data);
        // Activates the widget function.
        $commands[] = ajax_command_invoke(NULL, 'widget', array('twizo/user-login'));

        return array(
            '#type' => 'ajax',
            '#commands' => $commands,
        );
    } // Checks if the widget is enabled
    elseif ($account->twizo_user['widgetenabled'] == 0) {
        $user = user_load($uid, TRUE);
        return twizo_reload_page();
    } // Logs the user in if no phone number has been set
    else {
        $user = user_load($uid, TRUE);
        return twizo_reload_page();
    }
}

/**
 * Function that gets activated if the submit button is clicked.
 *
 * @return array
 */
function twizo_user_confirm_number_callback($form = NULL, $form_state = NULL){
    $uid = $form_state['uid'] !== NULL ? $form_state['uid'] : $_POST['uid'];
    $phoneNumber = twizo_get_user_phonenumber($uid, $form_state) != NULL ? twizo_get_user_phonenumber($uid, $form_state) : $_POST['number'];
    $sessionToken = isset($_POST['sessionToken']) ? $_POST['sessionToken'] : NULL;


    if (!isset($sessionToken)) {
        $data = array(
            'number' => $phoneNumber,
            'uid' => $uid
        );
        twizo_command('widgetSession', $data);
        $commands[] = ajax_command_invoke(NULL, 'widget', array('twizo/validate'));

        return array(
            '#type' => 'ajax',
            '#commands' => $commands,
        );
    } else {
        $twizoData = array(
            'sessionToken' => $sessionToken,
            'number' => $phoneNumber,
            'uid' => $uid,
        );
        // Gets the status of the widget from the Twizo API.
        $widgetStatus = twizo_command('getWidgetStatus', $twizoData);
        if ($widgetStatus == 'success') {
            $identifier = twizo_create_unique_user_identifier($uid);
            $data = array(
                'uid' => $uid,
                'number' => $phoneNumber,
                'identifier' => $identifier,
                'codesgenerated' => 0,
                'widgetenabled' => 1,
                'cookiehash' => null,
            );
            // Saves the user settings in the database.
            drupal_write_record('twizo_user', $data);
            return $form;
        } else {
            return twizo_reload_page();
        }
    }
}

/**
 * Set a cookie for trusted device.
 * @param $token
 * @return bool
 */
function twizo_set_cookie($token){
    setcookie('twizo_user_cookie', $token, time() + (86400 * 30), '/'); // Sets a cookie for 30 days.
    return true;
}

/**
 * Check the cookie for the trusted device.
 * @param $account
 * @return bool
 */
function twizo_check_cookie($account){
    $token = $_COOKIE['twizo_user_cookie'];
    $identifier = $account->twizo_user['identifier'];
    $hashedVersion = hash('sha512', sprintf('%s_%s', $identifier, $token));

    if($hashedVersion == $account->twizo_user['cookiehash']){
        return true;
    } else{
        return false;
    }
}

/**
 * Callback for the original login submit, makes sure the default login submit doesn't work.
 */
function twizo_unload_user(){
    global $user;
    $user = user_load(0);
    return $user;
}