<?php
/**
 * @file
 * This file is part of the Twizo Drupal 7 2fa extension.
 *
 * (c) Twizo <info@twizo.com>
 *
 * For the full copyright and license information, please view the LICENSE
 * File that was distributed with this source code.
 */

/**
 * Callback for saving changes made by the admin.
 * @param $form
 * @param $form_state
 * @return array
 */
function twizo_save_changes_callback($form = NULL, &$form_state = NULL){
    $uid = $form_state['values']['uid'] !== NULL ? $form_state['values']['uid'] : $_POST['uid'];
    $account = user_load($uid);
    $phoneNumber = isset($form_state['values']['number']) ? $form_state['values']['number'] : $_POST['number'];
    $sessionToken = isset($_POST['sessionToken']) ? $_POST['sessionToken'] : NULL;
    // Gets the value of the preferredMethod form dropdown useing $form['select_list']['options'][$key_value]
    $preferredMethod = isset($form_state['values']['twizo_preferred_method']) ? $form['twizo_preferred_method']['#options'][$form_state['values']['twizo_preferred_method']] : NULL;

    // If number in form is changed, open the widget and send verification code to new number
    if (!isset($sessionToken) && $phoneNumber != $account->twizo_user['number']) {
        $data = array(
            'number' => $phoneNumber,
            'uid' => $uid,
        );
        twizo_command('widgetSession', $data);
        $commands[] = ajax_command_invoke(NULL, 'widget', array('twizo/save'));

        return array(
            '#type' => 'ajax',
            '#commands' => $commands,
        );
    } elseif(isset($sessionToken)) {
        $arguments = array(
            'sessionToken' => $sessionToken,
            'number' => $phoneNumber,
        );
        // Gets the status of the widget from the Twizo API.
        $widgetStatus = twizo_command('getWidgetStatus', $arguments);
        if ($widgetStatus == 'success') {
            twizo_user_delete($account);
            $identifier = twizo_create_unique_user_identifier($uid);
            $data = array(
                'number' => $phoneNumber,
                'uid' => $uid,
                'identifier' => $identifier,
                'codesgenerated' => 0,
                'preferredmethod' => 'sms',
                'widgetenabled' => 1,
                'cookiehash' => NULL,
            );
            drupal_write_record('twizo_user', $data);
            drupal_set_message(t('Your changes have been saved'), 'status');
            return $form;
        } else{
            return twizo_reload_page();
        }
    } elseif($preferredMethod != $account->twizo_user['preferredmethod']) {
        $data = array(
            'number' => $phoneNumber,
            'preferredmethod' => $preferredMethod
        );

        twizo_user_update_preferredmethod($data);
        return twizo_reload_page();
    }else{
        return twizo_reload_page();
    }
}

/**
 * Callback for resetting the backupcodes.
 * @param $form
 * @param $form_state
 * @return array
 */
function twizo_reset_backup_code_callback($form = NULL, &$form_state = NULL){
    $uid = $form_state['values']['uid'] !== NULL ? $form_state['values']['uid'] : $_POST['uid'];
    $phoneNumber = twizo_get_user_phonenumber($uid, $form_state) != NULL ? twizo_get_user_phonenumber($uid, $form_state) : $_POST['number'];
    $sessionToken = isset($_POST['sessionToken']) ? $_POST['sessionToken'] : NULL;

    if (!isset($sessionToken)) {
        $data = array(
            'number' => $phoneNumber,
            'uid' => $uid
        );
        twizo_command('widgetSession', $data);
        $commands[] = ajax_command_invoke(NULL, 'widget', array('twizo/reset'));

        return array(
            '#type' => 'ajax',
            '#commands' => $commands,
        );
    } else {
        $data = array(
            'sessionToken' => $sessionToken,
            'number' => $phoneNumber,
            'uid' => $uid,
        );
        // Gets the status of the widget from the Twizo API.
        $widgetStatus = twizo_command('getWidgetStatus', $data);
        if ($widgetStatus == 'success') {
            $data = array('uid' => $uid);
            $response = twizo_command('updateBackupCode', $data);
            return drupal_json_output($response);
        } else{
            return twizo_reload_page();
        }
    }
}

/**
 * Callback for enabling the twizo widget.
 * @param $form
 * @param $form_state
 * @return array
 */
function twizo_user_enable_widget_callback($form, &$form_state){
    $account = user_load($form_state['values']['uid']);
    $data = array('widgetenabled' => $form_state['values']['widgetenabled'], 'number' => $account->twizo_user['number']);
    twizo_user_update_widgetenabled($data);

    return twizo_reload_page();
}

/**
 * @param $form
 * @param $form_state
 * @return array
 */
function twizo_generate_backup_code_callback($form, &$form_state){
    $data = array('uid' => $form_state['values']['uid']);
    $response = twizo_command('createBackupCode', $data);
    drupal_set_message('Backupcodes generated succesfully');
    $commands[] = ajax_command_invoke(NULL, 'showCodes', array($response));

    return array(
        '#type' => 'ajax',
        '#commands' => $commands);
}