<?php
/**
 * @file
 * This file is part of the Twizo Drupal 7 2fa extension.
 *
 * (c) Twizo <info@twizo.com>
 *
 * For the full copyright and license information, please view the LICENSE
 * File that was distributed with this source code.
 */

/**
 * @param $account
 * @return array|mixed
 */
function twizo_user_settings($account) {
    return drupal_get_form('twizo_user_settings_form', $account);
}

/**
 * @param $form
 * @param $form_state
 * @param $account
 * @return mixed
 */
function twizo_user_settings_form($form, &$form_state, $account){
    if(variable_get('twizo_enable_widget')) {
        global $user;
        $verificationTypes = twizo_command('getVerificationTypes', NULL);
        // Removes backupcode to be allowed as a preferred type for verification
        unset($verificationTypes[array_search('backupcode', $verificationTypes)]);
        $account = user_load($user->uid);
        $form['uid'] = array(
            '#type' => 'hidden',
            '#value' => $account->uid,
        );
        $form['number'] = array(
            '#type' => 'textfield',
            '#title' => t('Phone number'),
            '#description' => t('A confirmation code will be sent to via SMS to the number provided'),
            '#default_value' => isset($account->twizo_user['number']) ? $account->twizo_user['number'] : '',
            '#size' => 40,
            '#maxlength' => 255,
            '#required' => TRUE,
        );
        if(isset($account->twizo_user['number'])) {
            $form['widgetenabled'] = array(
                '#type' => 'checkbox',
                '#title' => t('Enable two factor authentication'),
                '#default_value' => $account->twizo_user['widgetenabled'],
                '#ajax' => array(
                    'callback' => 'twizo_user_enable_widget_callback',
                    'wrapper' => 'twizo_user_enable_widget_wrapper',
                ),
            );
            if($account->twizo_user['widgetenabled'] == 1){
                $form['twizo_preferred_method'] = array(
                    '#type' => 'select',
                    '#title' => t('Preferred login method'),
                    '#default_value' => array_search($account->twizo_user['preferredmethod'], $verificationTypes),
                    '#options' => $verificationTypes,
                    '#description' => t('Select preferred login method'),
                );
            }
            $form['reset_number'] = array(
                '#type' => 'submit',
                '#value' => t('Save'),
                '#ajax' => array(
                    'callback' => 'twizo_save_changes_callback',
                    'wrapper' => 'twizo_ajax_delete_number',
                    'method' => 'replace',
                ),
            );
            if ($account->twizo_user['codesgenerated'] && variable_get('twizo_enable_backupcode')) {
                $data = array('uid' => $user->uid);
                $codesLeft = twizo_command('getRemainingBackupCode', $data);
                if ($codesLeft != 1) {
                    drupal_set_message(t('You have ' . $codesLeft . ' backupcodes remaining.'));
                } else {
                    drupal_set_message(t('You have ' . $codesLeft . ' backupcode remaining.'));
                }
                $form['reset_backup_codes'] = array(
                    '#type' => 'submit',
                    '#value' => t('Reset backup codes'),
                    '#ajax' => array(
                        'callback' => 'twizo_reset_backup_code_callback',
                        'wrapper' => 'twizo_backupcodes_reset',
                    ),
                );
            } elseif (variable_get('twizo_enable_backupcode')){
                $form['generate_backup_code'] = array(
                    '#type' => 'submit',
                    '#value' => t('Generate backup codes'),
                    '#ajax' => array(
                        'callback' => 'twizo_generate_backup_code_callback',
                        'wrapper' => 'twizo_backup_code_wrapper',
                    ),
                );
            }
        } else{
            $form['confirm-number'] = array(
                '#type' => 'submit',
                '#value' => t('Confirm number'),
                '#validate' => 'twizo_validate_form',
                '#ajax' => array(
                    'callback' => 'twizo_user_confirm_number_callback',
                    'wrapper' => 'twizo-user-form',
                    'method' => 'replace',
                ),
            );
        }
    } else{
        $form['twizo_disabled'] = array(
            '#markup' => '<p>Twizo two factor authentication has been disabled by an admin.</p>',
        );
        //drupal_set_message('Twizo two factor authentication has been disabled by an admin.');
    }
    return $form;
}

