<?php
/**
 * @file
 * This file is part of the Twizo Drupal 7 2fa extension.
 *
 * (c) Twizo <info@twizo.com>
 *
 * For the full copyright and license information, please view the LICENSE
 * File that was distributed with this source code.
 */

/**
 * Implements hook_user_categories().
 */
function twizo_user_categories() {
    return array(
        array(
            'name' => 'twizo',
            'title' => t('Twizo SMS'),
            'weight' => 5,
        ),
    );
}

/**
 * Adds a twizo user to the database
 * @param array $data
 */
function twizo_add_user($data = array()){
    db_insert('twizo_user')
        ->fields(array(
            'uid' => $data['uid'],
            'number' => $data['number'],
            'identifier' => $data['identifier'],
            'codesgenerated' => $data['codesgenerated'],
            'widgetenabled' => $data['widgetenabled'],
        ))
        ->execute();
}

/**
 * Implements hook_user_load().
 */
function twizo_user_load($users) {
    // Load data from the {twizo_user} table for the user account.
    $result = db_select('twizo_user', 'u')
        ->fields('u', array('uid', 'number', 'identifier', 'codesgenerated', 'widgetenabled', 'preferredmethod', 'cookiehash'))
        ->condition('uid', array_keys($users), 'IN')
        ->execute();
    foreach ($result as $record) {
        if (!empty($record->uid)) {
            // Assign the twizo data to the user object.
            $users[$record->uid]->twizo_user = (array) $record;
        }
    }
}

/**
 * Implements hook_user_delete().
 */
function twizo_user_delete($account) {
    db_delete('twizo_user')
        ->condition('uid', $account->uid)
        ->execute();
}

/**
 * Updates the status of codesgenerated.
 * @param array $data
 */
function twizo_user_update_codesgenerated($data = array()){
    db_update('twizo_user')
        ->fields(array(
            'codesgenerated' => $data['codesgenerated']
        ))
        ->condition('number', $data['number'], '=')
        ->execute();
}

/**
 * Updates the status of widgetenabled.
 * @param array $data
 */
function twizo_user_update_widgetenabled($data = array()){
    db_update('twizo_user')
        ->fields(array(
            'widgetenabled' => $data['widgetenabled']
        ))
        ->condition('number', $data['number'], '=')
        ->execute();
}

/**
 * Updates the preferredmethod
 * @param array $data
 */
function twizo_user_update_preferredmethod($data = array()){
    db_update('twizo_user')
        ->fields(array(
            'preferredmethod' => $data['preferredmethod']
        ))
        ->condition('number', $data['number'], '=')
        ->execute();
}

/**
 * @param array $data
 */
function twizo_user_update_cookiehash($data = array()){
    db_update('twizo_user')
        ->fields(array(
            'cookiehash' => $data['cookiehash']
        ))
        ->condition('number', $data['number'], '=')
        ->execute();
}

/**
 * @return $phoneNumber of the user that tries to log in.
 */
function twizo_get_user_phonenumber($uid = null, $form_state = null){
    $account = user_load($uid);
    if(isset($account->twizo_user['number'])){
        $phoneNumber = $account->twizo_user['number'];
    } elseif(isset($form_state['values']['number'])) {
        $phoneNumber = $form_state['values']['number'];
    } else{
        $phoneNumber = null;
    }

    return $phoneNumber;
}

/**
 * Create a unique user identifier.
 * @return string with a unique generated identifier.
 */
function twizo_create_unique_user_identifier($uid){
    return md5(uniqid($uid, true));
}